@@ -25,9 +25,9 @@
 
 
 #---------------------------------------------------------------------------
-from BCs import rho
 from Foam import ref, man
 
+
 #---------------------------------------------------------------------------
 def _rhoBoundaryTypes( p ):
     pbf = p.ext_boundaryField()
@@ -65,6 +65,9 @@ def readThermophysicalProperties( runTime, mesh ):
 
 #---------------------------------------------------------------------------
 def _createFields( runTime, mesh ):
+    # Load boundary condition
+    from BCs import rho
+
     ref.ext_Info() << "Reading thermophysical properties\n" << ref.nl
     
     thermo = man.basicPsiThermo.New( mesh )
@@ -184,7 +187,7 @@ def main_standalone( argc, argv ):
     
     v_zero = ref.dimensionedScalar( ref.word( "v_zero" ), ref.dimVolume / ref.dimTime, 0.0)
     
-    ref.ext_Info() << "\nStarting time loopqqqqq\n" << ref.nl
+    ref.ext_Info() << "\nStarting time loop\n" << ref.nl
     
     while runTime.run() :
         # --- upwind interpolation of primitive fields on faces
@@ -249,7 +252,9 @@ def main_standalone( argc, argv ):
         runTime.increment()
         
         ref.ext_Info() << "Time = " << runTime.timeName() << ref.nl << ref.nl
-        phi << aphiv_pos * rho_pos + aphiv_neg * rho_neg
+        phi = None
+
+        phi = ref.surfaceScalarField( ref.word( "phi" ), aphiv_pos * rho_pos + aphiv_neg * rho_neg )
 
         phiUp = ( aphiv_pos * rhoU_pos + aphiv_neg * rhoU_neg) + ( a_pos * p_pos + a_neg * p_neg ) * mesh.Sf()
 
@@ -327,7 +332,7 @@ def main_standalone( argc, argv ):
 #--------------------------------------------------------------------------------------
 import sys, os
 from Foam import FOAM_VERSION
-if FOAM_VERSION( ">=", "020100" ):
+if FOAM_VERSION( ">=", "020000" ):
    if __name__ == "__main__" :
       argv = sys.argv
       os._exit( main_standalone( len( argv ), argv ) )
@@ -335,7 +340,7 @@ if FOAM_VERSION( ">=", "020100" ):
    pass   
 else:
    from Foam.OpenFOAM import ext_Info
-   ref.ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam2.1.0 or higher \n "
+   ref.ext_Info()<< "\nTo use this solver, It is necessary to SWIG OpenFoam2.0.0 or higher \n "
 
    
 #--------------------------------------------------------------------------------------
