@@ -292,7 +292,8 @@ class fixedRhoFvPatchScalarField( fixedValueFvPatchScalarField ):
 from Foam.template import getfvPatchFieldConstructorToTableBase_scalar
 class fvPatchFieldConstructorToTable_fixedRho( getfvPatchFieldConstructorToTableBase_scalar() ):
     def __init__( self ):
-        aBaseClass = getfvPatchFieldConstructorToTableBase_scalar()
+        # print self.__class__.__mro__[ 1 ]
+        aBaseClass = self.__class__.__mro__[ 1 ]
         aBaseClass.__init__( self )
         
         from Foam.OpenFOAM import word 
